searchData={"items":[{"type":"module","title":"MapLibre","doc":"Elixir bindings to [MapLibre Style\nSpecification](https://maplibre.org/maplibre-gl-js/docs/style-spec/).\n\nA MapLibre style is a document that defines the visual appearance of a map: what data to draw,\nthe order to draw it in, and how to style the data when drawing it. A style document is a JSON\nobject with specific root level and nested properties. To learn more about the style\nspecification and its properties, please see the\n[documentation](https://maplibre.org/maplibre-gl-js/docs/style-spec/)","ref":"MapLibre.html"},{"type":"module","title":"Composing maps - MapLibre","doc":"Laying out a basic MapLibre map consists of the following steps:\n\n    alias MapLibre, as: Ml\n\n    # Initialize the specification with the initial style and optionally some other root properties.\n    # If you don't provide a initial style, the default style will be loaded for you\n    Ml.new(center: {-74.5, 40}, zoom: 6)\n\n    # Add sources to make their data available\n    |> Ml.add_source(\"rwanda-provinces\",\n        type: :geojson,\n        data: \"https://maplibre.org/maplibre-gl-js/docs/assets/rwanda-provinces.geojson\"\n    )\n\n    # Add layers and refer them to sources to define their visual representation and make them visible\n    |> Ml.add_layer(id: \"rwanda-provinces\",\n        type: :fill,\n        source: \"rwanda-provinces\",\n        paint: [fill_color: \"#4A9661\"]\n    )","ref":"MapLibre.html#module-composing-maps"},{"type":"module","title":"Expressions - MapLibre","doc":"Expressions are extremely powerful and useful to render complex data. To use them just ensure\nthat you pass valid expressions following the rules and syntax of the [official\ndocumentation](https://maplibre.org/maplibre-gl-js/docs/style-spec/expressions/)","ref":"MapLibre.html#module-expressions"},{"type":"module","title":"Options - MapLibre","doc":"To provide a more Elixir-friendly experience, the options are automatically normalized, so you\ncan use keyword lists and snake-case atom keys.","ref":"MapLibre.html#module-options"},{"type":"function","title":"MapLibre.add_geo_source/4","doc":"Adds a GEO data to the sources in the specification.\n\nFor the `:geojson` type, provides integration with the [Geo](https://hexdocs.pm/geo/readme.html)\npackage.\n\n    geom = %Geo.LineString{coordinates: [\n      {-122.48369693756104, 37.83381888486939},\n      {-122.48348236083984, 37.83317489144141},\n      {-122.48339653015138, 37.83270036637107}\n    ]}\n\n    Ml.new()\n    |> Ml.add_geo_source(\"route\", geom)","ref":"MapLibre.html#add_geo_source/4"},{"type":"function","title":"MapLibre.add_geocode_source/3","doc":"Adds a data source by a given geocode to the sources in the specification.\n\nFor the `:geojson` type, provides integration with [Nominatim](https://nominatim.org).\n\nAny valid geocode is support in a free-form query string.\n\n    Ml.new()\n    |> Ml.add_geocode_source(\"brazil\", \"brazil\")\n    |> Ml.add_geocode_source(\"pilkington-avenue\", \"pilkington avenue, birmingham\")","ref":"MapLibre.html#add_geocode_source/3"},{"type":"function","title":"MapLibre.add_geocode_source/4","doc":"Same as `add_geocode_source/3` but for structured queries.\n\nThe last argument is an atom for the geocode type.\n\nSupported types: `:street`, `:city`, `:county`, `:state`, `:country` and `:postalcode`\n\n    Ml.new()\n    |> Ml.add_geocode_source(\"new-york\", \"new york\", :city)\n    |> Ml.add_geocode_source(\"ny\", \"new york\", :state)","ref":"MapLibre.html#add_geocode_source/4"},{"type":"function","title":"MapLibre.add_layer/2","doc":"Adds a layer to the layers list in the specification.\n\nA style's layers property lists all the layers available in the style. The type of layer is\nspecified by the `:type` property, and must be one of `:background`, `:fill`, `:line`,\n`:symbol`, `:raster`, `:circle`, `:fill_extrusion`, `:heatmap`, `:hillshade`.\n\nExcept for layers of the `:background` type, each layer needs to refer to a source. Layers take\nthe data that they get from a source, optionally filter features, and then define how those\nfeatures are styled.","ref":"MapLibre.html#add_layer/2"},{"type":"function","title":"Required - MapLibre.add_layer/2","doc":"* `:id` - Unique layer name.\n\n  * `:type` - One of:\n\n    * `:fill` -  A filled polygon with an optional stroked border.\n    * `:line` -  A stroked line.\n    * `:symbol` - An icon or a text label.\n    * `:circle` - A filled circle.\n    * `:heatmap` - A heatmap.\n    * `:fill_extrusion` - An extruded (3D) polygon.\n    * `:raster` - Raster map textures such as satellite imagery.\n    * `:hillshade` - Client-side hillshading visualization based on DEM data.\n    * `:background` - The background color or pattern of the map.\n\n  * `:source` - Name of a source description to be used for the layer. Required for all layer\n    types except `:background`.","ref":"MapLibre.html#add_layer/2-required"},{"type":"function","title":"Options - MapLibre.add_layer/2","doc":"* `:filter` - A expression specifying conditions on source features. Only features that match\n    the filter are displayed.\n\n  * `:layout` - Layout properties for the layer.\n\n  * `:maxzoom` - Optional number between 0 and 24 inclusive. The maximum zoom level for the\n    layer. At zoom levels equal to or greater than the `:maxzoom`, the layer will be hidden\n\n  * `:metadata` - Arbitrary properties useful to track with the layer, but do not influence\n    rendering. Properties should be prefixed to avoid collisions\n\n  * `:minzoom` - Optional number between 0 and 24 inclusive. The minimum zoom level for the\n    layer. At zoom levels less than the `:minzoom`, the layer will be hidden.\n\n  * `:paint` - Default paint properties for this layer.","ref":"MapLibre.html#add_layer/2-options"},{"type":"function","title":"Type specific - MapLibre.add_layer/2","doc":"* `:source_layer` - Layer to use from a vector tile source. Required for vector tile sources;\n    prohibited for all other source types, including GeoJSON sources.","ref":"MapLibre.html#add_layer/2-type-specific"},{"type":"function","title":"Examples - MapLibre.add_layer/2","doc":"|> Ml.add_layer(id: \"rwanda-provinces\",\n        type: :fill,\n        source: \"rwanda-provinces\",\n        paint: [fill_color: \"#4A9661\"]\n    )\n\nSee [the docs](https://maplibre.org/maplibre-gl-js/docs/style-spec/layers/) for more details.","ref":"MapLibre.html#add_layer/2-examples"},{"type":"function","title":"MapLibre.add_layer_below_labels/2","doc":"Same as `add_layer/2` but puts the given layer immediately below the labels","ref":"MapLibre.html#add_layer_below_labels/2"},{"type":"function","title":"MapLibre.add_source/3","doc":"Adds a data source to the sources in the specification.\n\nSources state which data the map should display. Specify the type of source with the `:type`\nproperty, which must be one of `:vector`, `:raster`, `:raster_dem`, `:geojson`, `:image` or `:video`.","ref":"MapLibre.html#add_source/3"},{"type":"function","title":"Examples - MapLibre.add_source/3","doc":"Ml.new()\n    |> Ml.add_source(\"rwanda-provinces\",\n          type: :geojson,\n          data: \"https://maplibre.org/maplibre-gl-js/docs/assets/rwanda-provinces.geojson\"\n    )\n\nSee [the docs](https://maplibre.org/maplibre-gl-js/docs/style-spec/sources/) for more details.","ref":"MapLibre.html#add_source/3-examples"},{"type":"function","title":"MapLibre.add_table_source/5","doc":"Adds points from tabular data to the sources in the specification.\n\nFor the `:geojson` type, provides integration with tabular data that implements the\n[Table](https://hexdocs.pm/table/Table.html) protocol.\n\nSupports data where the coordinates information is either in distinct columns or combined in a\nsingle one. In both cases you need to provide the pattern followed by the coordinates data:\n`:lng_lat` or `:lat_lng`\n\nProperties are also supported as a list of columns in the options.\n\n    earthquakes = %{\n      \"latitude\" => [32.3646, 32.3357, -9.0665, 52.0779, -57.7326],\n      \"longitude\" => [101.8781, 101.8413, -71.2103, 178.2851, 148.6945],\n      \"mag\" => [5.9, 5.6, 6.5, 6.3, 6.4]\n    }\n\n    Ml.new()\n    |> Ml.add_table_source(\"earthquakes\", earthquakes, {:lng_lat, [\"longitude\", \"latitude\"]})\n\n    earthquakes = %{\n      \"coordinates\" => [\"32.3646, 101.8781\", \"32.3357, 101.8413\", \"-9.0665, -71.2103\"],\n      \"mag\" => [5.9, 5.6, 6.5]\n    }\n\n    Ml.new()\n    |> Ml.add_table_source(\"earthquakes\", earthquakes, {:lat_lng, \"coordinates\"}, properties: [\"mag\"])","ref":"MapLibre.html#add_table_source/5"},{"type":"function","title":"MapLibre.glyphs/2","doc":"Sets the glyphs url in the specification.\n\nA style's glyphs property provides a URL template for loading signed-distance-field glyph sets\nin PBF format.\n\nSee [the docs](https://maplibre.org/maplibre-gl-js/docs/style-spec/glyphs/) for more details.","ref":"MapLibre.html#glyphs/2"},{"type":"function","title":"MapLibre.light/2","doc":"Sets the light options in the specification.\n\nA style's light property provides a global light source for that style. Since this property is\nthe light used to light extruded features, you will only see visible changes to your map style\nwhen modifying this property if you are using extrusions.","ref":"MapLibre.html#light/2"},{"type":"function","title":"Options - MapLibre.light/2","doc":"* `:anchor` - Whether extruded geometries are lit relative to the map or viewport. \"map\": The\n    position of the light source is aligned to the rotation of the map. \"viewport\": The position\n    of the light source is aligned to the rotation of the viewport. Default: \"viewport\"\n\n  * `:color` - Color tint for lighting extruded geometries. Default: \"#ffffff\"\n\n  * `:intensity` - Intensity of lighting (on a scale from 0 to 1). Higher numbers will present\n    as more extreme contrast. Default: 0.5\n\n  * `:position` - Position of the light source relative to lit (extruded) geometries, in {r\n    radial coordinate, a azimuthal angle, p polar angle} where r indicates the distance from the\n    center of the base of an object to its light, a indicates the position of the light relative\n    to 0° (0° when light.anchor is set to viewport corresponds to the top of the viewport, or 0°\n    when light.anchor is set to map corresponds to due north, and degrees proceed clockwise),\n    and p indicates the height of the light (from 0°, directly above, to 180°, directly below).\n    Default: {1.15, 210, 30}\n\nSee [the docs](https://maplibre.org/maplibre-gl-js/docs/style-spec/light/) for more details.","ref":"MapLibre.html#light/2-options"},{"type":"function","title":"MapLibre.metadata/3","doc":"Adds or updates the map metadata properties. Metadata are arbitrary properties useful to track\nwith the style, but do not influence rendering. Properties should be prefixed to avoid\ncollisions, like \"mapbox:\".","ref":"MapLibre.html#metadata/3"},{"type":"function","title":"MapLibre.new/1","doc":"Returns a style specification wrapped in the `MapLibre` struct. If you don't provide a initial\nstyle, the [default style](https://demotiles.maplibre.org/style.json) will be loaded for you. If\nyou wish to build a new style completely from scratch, pass an empty map `%{}` as `:style`\noption. The style specification version will be automatically set to 8.","ref":"MapLibre.html#new/1"},{"type":"function","title":"Options - MapLibre.new/1","doc":"Only the following properties are allowed directly on `new/1`\n\n  * `:bearing` -  Default bearing, in degrees. The bearing is the compass direction that is\n    \"up\"; for example, a bearing of 90° orients the map so that east is up. This value will be\n    used only if the map has not been positioned by other means (e.g. map options or user\n    interaction). Default: 0\n\n  * `:center` - Default map center in longitude and latitude. The style center will be used only\n    if the map has not been positioned by other means (e.g. map options or user interaction).\n    Default: {0, 0}\n\n  * `:name` - A human-readable name for the style.\n\n  * `:pitch` - Default pitch, in degrees. Zero is perpendicular to the surface, for a look\n    straight down at the map, while a greater value like 60 looks ahead towards the horizon. The\n    style pitch will be used only if the map has not been positioned by other means (e.g. map\n    options or user interaction). Default: 0\n\n  * `:zoom` - Default zoom level. The style zoom will be used only if the map has not been\n    positioned by other means (e.g. map options or user interaction).\n\n  * `:style` - The initial style specification. Three built-in initial styles are available:\n    `:default`, `:street` and `:terrain`.\n\n  * `:key` - The [Maptiler](https://www.maptiler.com) key to be used by the built-in `:street`\n    and `:terrain` styles. If you don't provide a key, the default key (strictly for\n    non-commercial use) will be used.\n\nTo manipulate any other [style root\nproperties](https://maplibre.org/maplibre-gl-js/docs/style-spec/root/), use the\ncorresponding functions","ref":"MapLibre.html#new/1-options"},{"type":"function","title":"Examples - MapLibre.new/1","doc":"Ml.new(\n      center: {-74.5, 40},\n      zoom: 9,\n      name: \"Rwanda population density\"\n    )\n    |> ...\n\nSee [the docs](https://maplibre.org/maplibre-gl-js/docs/style-spec/) for more details.","ref":"MapLibre.html#new/1-examples"},{"type":"function","title":"MapLibre.points/2","doc":"","ref":"MapLibre.html#points/2"},{"type":"function","title":"MapLibre.sprite/2","doc":"Sets the sprite url in the specification.\n\nA style's sprite property supplies a URL template for loading small images to use in rendering\n`:background_pattern`, `:fill_pattern`, `:line_pattern`,`:fill_extrusion_pattern` and `:icon_image` style\nproperties.\n\nSee [the docs](https://maplibre.org/maplibre-gl-js/docs/style-spec/sprite/) for more details.","ref":"MapLibre.html#sprite/2"},{"type":"function","title":"MapLibre.to_spec/1","doc":"Returns the underlying MapLibre specification. The result is a nested Elixir data structure that\nserializes to MapLibre style JSON specification.\n\nSee [the docs](https://maplibre.org/maplibre-gl-js/docs/style-spec/) for more details.","ref":"MapLibre.html#to_spec/1"},{"type":"function","title":"MapLibre.transition/2","doc":"Defines a global default transition settings in the specification.\n\nA transition property controls timing for the interpolation between a transitionable style\nproperty's previous value and new value. A style's root transition property provides global\ntransition defaults for that style.\n\nSee [the docs](https://maplibre.org/maplibre-gl-js/docs/style-spec/transition/) for more\ndetails.","ref":"MapLibre.html#transition/2"},{"type":"function","title":"MapLibre.update_layer/3","doc":"Updates a layer that was already defined in the specification","ref":"MapLibre.html#update_layer/3"},{"type":"type","title":"MapLibre.coordinates_columns/0","doc":"","ref":"MapLibre.html#t:coordinates_columns/0"},{"type":"type","title":"MapLibre.coordinates_combined/0","doc":"","ref":"MapLibre.html#t:coordinates_combined/0"},{"type":"type","title":"MapLibre.coordinates_format/0","doc":"","ref":"MapLibre.html#t:coordinates_format/0"},{"type":"type","title":"MapLibre.coordinates_spec/0","doc":"","ref":"MapLibre.html#t:coordinates_spec/0"},{"type":"type","title":"MapLibre.spec/0","doc":"","ref":"MapLibre.html#t:spec/0"},{"type":"type","title":"MapLibre.t/0","doc":"","ref":"MapLibre.html#t:t/0"}],"content_type":"text/markdown"}